==> aria2-1.10.6.tar.gz: aria2-1.10.6/src/DHTTaskQueueImpl.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "DHTTaskQueueImpl.h"
#include "DHTTask.h"
#include "Logger.h"
#include "LogFactory.h"

namespace aria2 {

namespace {
const size_t NUM_CONCURRENT_TASK = 5;
} // namespace

DHTTaskQueueImpl::DHTTaskQueueImpl():
  periodicTaskQueue1_(NUM_CONCURRENT_TASK),
  periodicTaskQueue2_(NUM_CONCURRENT_TASK),
  immediateTaskQueue_(NUM_CONCURRENT_TASK),
  logger_(LogFactory::getInstance()) {}

DHTTaskQueueImpl::~DHTTaskQueueImpl() {}

void DHTTaskQueueImpl::executeTask()
{
  if(logger_->debug()) {
    logger_->debug("Updating periodicTaskQueue1");
  }
  periodicTaskQueue1_.update();
  if(logger_->debug()) {
    logger_->debug("Updating periodicTaskQueue2");
  }
  periodicTaskQueue2_.update();
  if(logger_->debug()) {
    logger_->debug("Updating immediateTaskQueue");
  }
  immediateTaskQueue_.update();
}

void DHTTaskQueueImpl::addPeriodicTask1(const SharedHandle<DHTTask>& task)
{
  periodicTaskQueue1_.addTask(task);
}

void DHTTaskQueueImpl::addPeriodicTask2(const SharedHandle<DHTTask>& task)
{
  periodicTaskQueue2_.addTask(task);
}

void DHTTaskQueueImpl::addImmediateTask(const SharedHandle<DHTTask>& task)
{
  immediateTaskQueue_.addTask(task);
}

} // namespace aria2

==> aria2-1.14.2.tar.gz: aria2-1.14.2/src/DHTTaskQueueImpl.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "DHTTaskQueueImpl.h"
#include "DHTTask.h"
#include "Logger.h"
#include "LogFactory.h"

namespace aria2 {

namespace {
const size_t NUM_CONCURRENT_TASK = 5;
} // namespace

DHTTaskQueueImpl::DHTTaskQueueImpl()
  : periodicTaskQueue1_(NUM_CONCURRENT_TASK),
    periodicTaskQueue2_(NUM_CONCURRENT_TASK),
    immediateTaskQueue_(NUM_CONCURRENT_TASK)
{}

DHTTaskQueueImpl::~DHTTaskQueueImpl() {}

void DHTTaskQueueImpl::executeTask()
{
  A2_LOG_DEBUG("Updating periodicTaskQueue1");
  periodicTaskQueue1_.update();
  A2_LOG_DEBUG("Updating periodicTaskQueue2");
  periodicTaskQueue2_.update();
  A2_LOG_DEBUG("Updating immediateTaskQueue");
  immediateTaskQueue_.update();
}

void DHTTaskQueueImpl::addPeriodicTask1(const SharedHandle<DHTTask>& task)
{
  periodicTaskQueue1_.addTask(task);
}

void DHTTaskQueueImpl::addPeriodicTask2(const SharedHandle<DHTTask>& task)
{
  periodicTaskQueue2_.addTask(task);
}

void DHTTaskQueueImpl::addImmediateTask(const SharedHandle<DHTTask>& task)
{
  immediateTaskQueue_.addTask(task);
}

} // namespace aria2
